@@ -120,3 +120,14 @@ class RethinkDBClient(BaseStorageClient):
 
         items = [item async for item in result]
         return [obj_cls(**item) for item in items]
+
+    async def count(self, obj_cls, object_space, object_type, filter):
+        await self.init_table(object_space, object_type, obj_cls._indexes)
+
+        return await r.db(
+            object_space
+        ).table(
+            object_type
+        ).filter(
+            filter.fields
+        ).count().run(self._connection)
